{"00000:1": "

    $ dexy reporters\nALIAS      DIRECTORY            INFO\nlong       output-long          Creates complete dexy output with files given long, unique filenames.\noutput     output               Creates canonical dexy output with files given short filenames.\nrun                            \nws         output-site          Applies a template to create a website from your dexy output.\n

\n"}